@@ -215,7 +215,7 @@ class DeskbarApplet:
 				break
 					
 	def on_about (self, component, verb):
-		show_about()
+		show_about(self.applet)
 	
 	def on_preferences (self, component, verb):
 		show_preferences(self, self.loader, self.module_list)
@@ -298,9 +298,10 @@ class DeskbarApplet:
 		return False
 	
 	def on_applet_button_release(self, widget, event):
-		# The check for middle_click != None is to "fix" bug 355687
+		# The check for middle_click != None is to fix bug 355687
+		# this happens when the mouse is middle_clicked then moved inside
+		# the entry and released. In this case we ignore it.
 		if self.middle_click is None:
-			print "WARN, DeskbarApplet: self.middle_click is None on button release"
 			return
 			
 		if event.button == 2:
