@@ -12,9 +12,13 @@ class DeskbarAppletPreferences:
 		self.GCONF_EXPAND = deskbar.GCONF_EXPAND
 		self.GCONF_UI_NAME = deskbar.GCONF_UI_NAME
 		
-		# This preference is shared across all applet instances, unlike
-		# width, which is per-instance.
+		# These preferences are shared across all applet instances
+		# unlike width, which is per-instance.
 		self.GCONF_KEYBINDING = deskbar.GCONF_KEYBINDING
+		self.GCONF_MINCHARS = deskbar.GCONF_MINCHARS
+		self.GCONF_TYPINGDELAY = deskbar.GCONF_TYPINGDELAY
+		self.GCONF_USE_SELECTION = deskbar.GCONF_USE_SELECTION
+		self.GCONF_CLEAR_ENTRY = deskbar.GCONF_CLEAR_ENTRY
 		
 		# Retreive this applet's pref folder
 		path = applet.get_preferences_key()
